@@ -1,4 +1,5 @@
 test_that("stan respects changes to control parameters", {
+  cat("\n\n", as.character(Sys.time()), "--------------- test_misc.R / control params ---------------\n\n")
   mpm <- money_priming_sub()
 
   res <- phacking_meta(mpm$yi, mpm$vi, alpha_select = 1e-10,
@@ -12,6 +13,7 @@ test_that("stan respects changes to control parameters", {
 })
 
 test_that("study counts are right even with a strange alpha_select", {
+  cat("\n\n", as.character(Sys.time()), "--------------- test_misc.R / alpha_select ---------------\n\n")
   mpm <- money_priming_sub()
   alpha <- 1e-10
   z_alpha <- qnorm(1 - alpha / 2)
@@ -24,8 +26,9 @@ test_that("study counts are right even with a strange alpha_select", {
   expect_equal(sum(mpm$affirm == 0), res$values$k_nonaffirmative)
 })
 
-test_that("one nonaffirmative runs", {
-  # try passing only 1 nonaffirmative; should still run but have warnings
-  w <- capture_warnings(phacking_meta(yi = 0.2, sei = 0.2, parallelize = FALSE))
-  expect_gt(length(w), 0)
-})
+# test_that("one nonaffirmative runs", {
+#   cat("\n\n", as.character(Sys.time()), "--------------- test_misc.R / nonaffirmative runs ---------------\n\n")
+#   # try passing only 1 nonaffirmative; should still run but have warnings
+#   w <- capture_warnings(phacking_meta(yi = 0.2, sei = 0.2, parallelize = FALSE))
+#   expect_gt(length(w), 0)
+# })
